# coding: utf-8

# flake8: noqa
"""
    😸 Cheshire-Cat API

    Customizable AI architecture  # noqa: E501

    The version of the OpenAPI document: 0.0.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from cheshire_cat_api.models.body_upload_url import BodyUploadUrl
from cheshire_cat_api.models.http_validation_error import HTTPValidationError
from cheshire_cat_api.models.location_inner import LocationInner
from cheshire_cat_api.models.setting_body import SettingBody
from cheshire_cat_api.models.validation_error import ValidationError
